#
# spec file for package butane
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Neal Gompa.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           butane
Version:        0.18.0
Release:        1.2
Summary:        Tool to generate Ignition configs from Butane Configs
Group:          System/Management
License:        Apache-2.0
URL:            https://github.com/coreos/butane
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  golang(API) >= 1.18

# Upgrade from old fcct/ignition-config-transpiler
Obsoletes:      ignition-config-transpiler < %{version}-%{release}
Provides:       ignition-config-transpiler = %{version}-%{release}
Provides:       ignition-config-transpiler%{?_isa} = %{version}-%{release}

%description
Butane translates human-readable Butane Configs into machine-readable
Ignition configs for provisioning operating systems that use Ignition.

%prep
%autosetup -p1

%build
go build -mod=vendor -buildmode=pie -ldflags "-X github.com/coreos/butane/internal/version.Raw=%{version}" -a -v -x -o ./butane internal/main.go

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 0755 ./butane %{buildroot}%{_bindir}
ln -s butane %{buildroot}%{_bindir}/ignition-config-transpiler
ln -s butane %{buildroot}%{_bindir}/fcct

%files
%license LICENSE
%doc docs README.md NEWS.md
%{_bindir}/butane
%{_bindir}/ignition-config-transpiler
%{_bindir}/fcct

%changelog
* Wed Jun 21 2023 Osama Alrifai <osamaalrifai18@gmail.com>
- update to version 0.18.0
  Breaking changes
    Remove deprecated rhcos variant
  Features
    Support offline Tang provisioning via pre-shared advertisement (fcos 1.5.0+,
    openshift 4.14.0-exp)
    Support local file embedding for SSH keys and systemd units (fcos 1.5.0+,
    flatcar 1.1.0+, openshift 4.14.0-exp, r4e 1.1.0+)
    Allow enabling discard passthrough on LUKS devices (fcos 1.5.0+,
    flatcar 1.1.0+, openshift 4.14.0-exp)
    Allow specifying arbitrary LUKS open options (fcos 1.5.0+,
    flatcar 1.1.0+, openshift 4.14.0-exp)
    Allow specifying user password hash (openshift 4.13.0+)
    Stabilize Fedora CoreOS spec 1.5.0, targeting Ignition spec 3.4.0
    Stabilize Flatcar spec 1.1.0, targeting Ignition spec 3.4.0
    Stabilize OpenShift spec 4.13.0, targeting Ignition spec 3.2.0
    Stabilize RHEL for Edge spec 1.1.0, targeting Ignition spec 3.4.0
    Add Fedora CoreOS spec 1.6.0-experimental, targeting Ignition spec
    3.5.0-experimental
    Add Flatcar spec 1.2.0-experimental, targeting Ignition spec
    3.5.0-experimental
    Add OpenShift spec 4.14.0-experimental, targeting Ignition spec
    3.5.0-experimental
    Add RHEL for Edge spec 1.2.0-experimental, targeting Ignition spec
    3.5.0-experimental
  Bug fixes
    Use systemd default dependencies in mount units for Tang-backed LUKS volumes
    Allow setting storage.trees.local to the --files-dir directory
  Misc. changes
    Roll back to Ignition spec 3.2.0 (openshift 4.13.0)
    Drop extensions section (fcos 1.5.0+, openshift 4.13.0+)
    Drop LuksOption and RaidOption types (Go API for fcos 1.5.0+,
    flatcar 1.1.0+, openshift 4.14.0-experimental)
    Require Go 1.18+
  Docs changes
    Document that hash fields describe decompressed data
    Clarify spec docs for files/luks hash fields
    Document SSH key file path used by OpenShift 4.13+ (openshift)
    Document command to generate GRUB password hashes
* Thu Feb 16 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 0.17.0
  - Add RHEL for Edge (r4e) spec 1.0.0 and 1.1.0-experimental,
    targeting
  - Ignition spec 3.3.0 and 3.4.0-experimental respectively
  - Fix version string in release container
- Changes in version 0.16.0
  - Stabilize OpenShift spec 4.12.0, targeting Ignition spec 3.2.0
  - Add OpenShift spec 4.13.0-experimental, targeting Ignition
    spec 3.4.0-experimental
  - Ship aarch64 macOS binary in GitHub release artifacts
  - Roll back to Ignition spec 3.2.0 (openshift 4.12.0)
  - Require Go 1.17+
  - test: Check docs on macOS and Windows if dependencies are available
  - Document passwd.users.should_exist and passwd.groups.should_exist
    fields (fcos 1.2.0+, flatcar, rhcos)
  - Clarify spec docs for files/directories/links group fields
  - Document that user/group fields aren't applied to hard links
- Changes in version 0.15.0
  - Return selected compression field value from MakeDataURL() (Go API)
  - Add Flatcar spec 1.0.0 and 1.1.0-experimental, targeting Ignition
    spec 3.3.0 and 3.4.0-experimental respectively
  - Stabilize OpenShift spec 4.11.0, targeting Ignition spec 3.2.0
  - Add OpenShift spec 4.12.0-experimental, targeting Ignition
    spec 3.4.0-experimental
  - Add arm64 support to container
  - Add GRUB password support (fcos 1.5.0-exp, openshift 4.12.0-exp)
  - Add TranslationSet AddFromCommonObject() and Map() methods (Go API)
  - Set compression field for uncompressed inline/local resources, fixing
    provisioning failure when merged with a compressed parent resource
  - Fix local file inclusion on Windows
  - Fix build script on Windows
  - Derive container from Fedora image to support use in multi-stage builds
  - Fail if setuid/setgid/sticky mode bits specified (openshift 4.10.0+)
  - Update to Ignition 2.14.0
  - Roll back to Ignition spec 3.2.0 (openshift 4.11.0)
  - Support arn URL scheme (fcos 1.5.0-exp, openshift 4.12.0-exp)
  - Document support status of setuid/setgid/sticky mode bits in each spec
  - Document support for gs URLs (openshift 4.8.0+)
  - Document support for compression field (openshift 4.8.0 - 4.9.0)
  - Correctly document supported URL schemes (openshift 4.10.0)
  - examples: Use containerized mkpasswd
  - Convert NEWS to Markdown and move to docs site
* Thu Mar 17 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.14.0
  - Correctly fail on validation warnings if --strict is specified
  - Drop support for Go 1.13 and 1.14
  - Support none filesystem format
  - Fix incorrect config paths in validation reports on 386 architecture
- Drop obsolete butane-0.11.0-fix-vcontext-report-copy.patch
* Fri Apr  9 2021 Neal Gompa <ngompa13@gmail.com>
- Initial package to replace ignition-config-transpiler/fcct
